/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'toolbar', 'bg', {
	toolbarCollapse: 'Свиване на лентата с инструменти',
	toolbarExpand: 'Разширяване на лентата с инструменти',
	toolbarGroups: {
		document: 'Документ',
		clipboard: 'Клипборд/Отмяна',
		editing: 'Редакция',
		forms: 'Форми',
		basicstyles: 'Базови стилове',
		paragraph: 'Параграф',
		links: 'Връзки',
		insert: 'Вмъкване',
		styles: 'Стилове',
		colors: 'Цветове',
		tools: 'Инструменти'
	},
	toolbars: 'Ленти с инструменти'
} );
